diff mbox series

[ovs-dev,v2] lflow.c: Rename function convert_acts_to_expr to convert_match_to_expr.

Message ID 1600272334-5936-1-git-send-email-hzhou@ovn.org
State Accepted
Headers show
Series [ovs-dev,v2] lflow.c: Rename function convert_acts_to_expr to convert_match_to_expr. | expand

Commit Message

Han Zhou Sept. 16, 2020, 4:05 p.m. UTC
The name was misleading because it in fact parses lflow match instead
of actions.

Fixes: 1213bc8270 ("ovn-controller: Cache logical flow expr matches.")
Cc: Numan Siddique <numans@ovn.org>
Acked-by: Numan Siddique <numans@ovn.org>
Signed-off-by: Han Zhou <hzhou@ovn.org>
---
v1 -> v2: Address Dumitru's comments for the indentation.

 controller/lflow.c | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

Comments

Dumitru Ceara Sept. 17, 2020, 7:25 a.m. UTC | #1
On 9/16/20 6:05 PM, Han Zhou wrote:
> The name was misleading because it in fact parses lflow match instead
> of actions.
> 
> Fixes: 1213bc8270 ("ovn-controller: Cache logical flow expr matches.")
> Cc: Numan Siddique <numans@ovn.org>
> Acked-by: Numan Siddique <numans@ovn.org>
> Signed-off-by: Han Zhou <hzhou@ovn.org>
> ---
> v1 -> v2: Address Dumitru's comments for the indentation.
> 
>  controller/lflow.c | 20 ++++++++++----------
>  1 file changed, 10 insertions(+), 10 deletions(-)
> 
> diff --git a/controller/lflow.c b/controller/lflow.c
> index e785866..cf5cf9f 100644
> --- a/controller/lflow.c
> +++ b/controller/lflow.c
> @@ -720,15 +720,15 @@ add_matches_to_flow_table(const struct sbrec_logical_flow *lflow,
>      ofpbuf_uninit(&ofpacts);
>  }
>  
> -/* Converts the actions and returns the simplified expre tree.
> +/* Converts the match and returns the simplified expre tree.
>   * The caller should evaluate the conditions and normalize the
>   * expr tree. */
>  static struct expr *
> -convert_acts_to_expr(const struct sbrec_logical_flow *lflow,
> -                     struct expr *prereqs,
> -                     struct lflow_ctx_in *l_ctx_in,
> -                     struct lflow_ctx_out *l_ctx_out,
> -                     bool *pg_addr_set_ref, char **errorp)
> +convert_match_to_expr(const struct sbrec_logical_flow *lflow,
> +                      struct expr *prereqs,
> +                      struct lflow_ctx_in *l_ctx_in,
> +                      struct lflow_ctx_out *l_ctx_out,
> +                      bool *pg_addr_set_ref, char **errorp)
>  {
>      struct sset addr_sets_ref = SSET_INITIALIZER(&addr_sets_ref);
>      struct sset port_groups_ref = SSET_INITIALIZER(&port_groups_ref);
> @@ -861,8 +861,8 @@ consider_logical_flow(const struct sbrec_logical_flow *lflow,
>      struct expr *expr = NULL;
>      if (!l_ctx_out->lflow_cache_map) {
>          /* Caching is disabled. */
> -        expr = convert_acts_to_expr(lflow, prereqs, l_ctx_in,
> -                                    l_ctx_out, NULL, &error);
> +        expr = convert_match_to_expr(lflow, prereqs, l_ctx_in,
> +                                     l_ctx_out, NULL, &error);
>          if (error) {
>              expr_destroy(prereqs);
>              ovnacts_free(ovnacts.data, ovnacts.size);
> @@ -924,8 +924,8 @@ consider_logical_flow(const struct sbrec_logical_flow *lflow,
>  
>      bool pg_addr_set_ref = false;
>      if (!expr) {
> -        expr = convert_acts_to_expr(lflow, prereqs, l_ctx_in, l_ctx_out,
> -                                    &pg_addr_set_ref, &error);
> +        expr = convert_match_to_expr(lflow, prereqs, l_ctx_in, l_ctx_out,
> +                                     &pg_addr_set_ref, &error);
>          if (error) {
>              expr_destroy(prereqs);
>              ovnacts_free(ovnacts.data, ovnacts.size);
> 

Acked-by: Dumitru Ceara <dceara@redhat.com>

Thanks,
Dumitru
Han Zhou Sept. 17, 2020, 7:31 a.m. UTC | #2
On Thu, Sep 17, 2020 at 12:25 AM Dumitru Ceara <dceara@redhat.com> wrote:
>
> On 9/16/20 6:05 PM, Han Zhou wrote:
> > The name was misleading because it in fact parses lflow match instead
> > of actions.
> >
> > Fixes: 1213bc8270 ("ovn-controller: Cache logical flow expr matches.")
> > Cc: Numan Siddique <numans@ovn.org>
> > Acked-by: Numan Siddique <numans@ovn.org>
> > Signed-off-by: Han Zhou <hzhou@ovn.org>
> > ---
> > v1 -> v2: Address Dumitru's comments for the indentation.
> >
> >  controller/lflow.c | 20 ++++++++++----------
> >  1 file changed, 10 insertions(+), 10 deletions(-)
> >
> > diff --git a/controller/lflow.c b/controller/lflow.c
> > index e785866..cf5cf9f 100644
> > --- a/controller/lflow.c
> > +++ b/controller/lflow.c
> > @@ -720,15 +720,15 @@ add_matches_to_flow_table(const struct
sbrec_logical_flow *lflow,
> >      ofpbuf_uninit(&ofpacts);
> >  }
> >
> > -/* Converts the actions and returns the simplified expre tree.
> > +/* Converts the match and returns the simplified expre tree.
> >   * The caller should evaluate the conditions and normalize the
> >   * expr tree. */
> >  static struct expr *
> > -convert_acts_to_expr(const struct sbrec_logical_flow *lflow,
> > -                     struct expr *prereqs,
> > -                     struct lflow_ctx_in *l_ctx_in,
> > -                     struct lflow_ctx_out *l_ctx_out,
> > -                     bool *pg_addr_set_ref, char **errorp)
> > +convert_match_to_expr(const struct sbrec_logical_flow *lflow,
> > +                      struct expr *prereqs,
> > +                      struct lflow_ctx_in *l_ctx_in,
> > +                      struct lflow_ctx_out *l_ctx_out,
> > +                      bool *pg_addr_set_ref, char **errorp)
> >  {
> >      struct sset addr_sets_ref = SSET_INITIALIZER(&addr_sets_ref);
> >      struct sset port_groups_ref = SSET_INITIALIZER(&port_groups_ref);
> > @@ -861,8 +861,8 @@ consider_logical_flow(const struct
sbrec_logical_flow *lflow,
> >      struct expr *expr = NULL;
> >      if (!l_ctx_out->lflow_cache_map) {
> >          /* Caching is disabled. */
> > -        expr = convert_acts_to_expr(lflow, prereqs, l_ctx_in,
> > -                                    l_ctx_out, NULL, &error);
> > +        expr = convert_match_to_expr(lflow, prereqs, l_ctx_in,
> > +                                     l_ctx_out, NULL, &error);
> >          if (error) {
> >              expr_destroy(prereqs);
> >              ovnacts_free(ovnacts.data, ovnacts.size);
> > @@ -924,8 +924,8 @@ consider_logical_flow(const struct
sbrec_logical_flow *lflow,
> >
> >      bool pg_addr_set_ref = false;
> >      if (!expr) {
> > -        expr = convert_acts_to_expr(lflow, prereqs, l_ctx_in,
l_ctx_out,
> > -                                    &pg_addr_set_ref, &error);
> > +        expr = convert_match_to_expr(lflow, prereqs, l_ctx_in,
l_ctx_out,
> > +                                     &pg_addr_set_ref, &error);
> >          if (error) {
> >              expr_destroy(prereqs);
> >              ovnacts_free(ovnacts.data, ovnacts.size);
> >
>
> Acked-by: Dumitru Ceara <dceara@redhat.com>
>
> Thanks,
> Dumitru
>

Thanks Numan and Dumitru. I applied this to master.
Numan Siddique Sept. 17, 2020, 10:26 a.m. UTC | #3
On Thu, Sep 17, 2020 at 1:01 PM Han Zhou <hzhou@ovn.org> wrote:

> On Thu, Sep 17, 2020 at 12:25 AM Dumitru Ceara <dceara@redhat.com> wrote:
> >
> > On 9/16/20 6:05 PM, Han Zhou wrote:
> > > The name was misleading because it in fact parses lflow match instead
> > > of actions.
> > >
> > > Fixes: 1213bc8270 ("ovn-controller: Cache logical flow expr matches.")
> > > Cc: Numan Siddique <numans@ovn.org>
> > > Acked-by: Numan Siddique <numans@ovn.org>
> > > Signed-off-by: Han Zhou <hzhou@ovn.org>
> > > ---
> > > v1 -> v2: Address Dumitru's comments for the indentation.
> > >
> > >  controller/lflow.c | 20 ++++++++++----------
> > >  1 file changed, 10 insertions(+), 10 deletions(-)
> > >
> > > diff --git a/controller/lflow.c b/controller/lflow.c
> > > index e785866..cf5cf9f 100644
> > > --- a/controller/lflow.c
> > > +++ b/controller/lflow.c
> > > @@ -720,15 +720,15 @@ add_matches_to_flow_table(const struct
> sbrec_logical_flow *lflow,
> > >      ofpbuf_uninit(&ofpacts);
> > >  }
> > >
> > > -/* Converts the actions and returns the simplified expre tree.
> > > +/* Converts the match and returns the simplified expre tree.
> > >   * The caller should evaluate the conditions and normalize the
> > >   * expr tree. */
> > >  static struct expr *
> > > -convert_acts_to_expr(const struct sbrec_logical_flow *lflow,
> > > -                     struct expr *prereqs,
> > > -                     struct lflow_ctx_in *l_ctx_in,
> > > -                     struct lflow_ctx_out *l_ctx_out,
> > > -                     bool *pg_addr_set_ref, char **errorp)
> > > +convert_match_to_expr(const struct sbrec_logical_flow *lflow,
> > > +                      struct expr *prereqs,
> > > +                      struct lflow_ctx_in *l_ctx_in,
> > > +                      struct lflow_ctx_out *l_ctx_out,
> > > +                      bool *pg_addr_set_ref, char **errorp)
> > >  {
> > >      struct sset addr_sets_ref = SSET_INITIALIZER(&addr_sets_ref);
> > >      struct sset port_groups_ref = SSET_INITIALIZER(&port_groups_ref);
> > > @@ -861,8 +861,8 @@ consider_logical_flow(const struct
> sbrec_logical_flow *lflow,
> > >      struct expr *expr = NULL;
> > >      if (!l_ctx_out->lflow_cache_map) {
> > >          /* Caching is disabled. */
> > > -        expr = convert_acts_to_expr(lflow, prereqs, l_ctx_in,
> > > -                                    l_ctx_out, NULL, &error);
> > > +        expr = convert_match_to_expr(lflow, prereqs, l_ctx_in,
> > > +                                     l_ctx_out, NULL, &error);
> > >          if (error) {
> > >              expr_destroy(prereqs);
> > >              ovnacts_free(ovnacts.data, ovnacts.size);
> > > @@ -924,8 +924,8 @@ consider_logical_flow(const struct
> sbrec_logical_flow *lflow,
> > >
> > >      bool pg_addr_set_ref = false;
> > >      if (!expr) {
> > > -        expr = convert_acts_to_expr(lflow, prereqs, l_ctx_in,
> l_ctx_out,
> > > -                                    &pg_addr_set_ref, &error);
> > > +        expr = convert_match_to_expr(lflow, prereqs, l_ctx_in,
> l_ctx_out,
> > > +                                     &pg_addr_set_ref, &error);
> > >          if (error) {
> > >              expr_destroy(prereqs);
> > >              ovnacts_free(ovnacts.data, ovnacts.size);
> > >
> >
> > Acked-by: Dumitru Ceara <dceara@redhat.com>
> >
> > Thanks,
> > Dumitru
> >
>
> Thanks Numan and Dumitru. I applied this to master.
>

Thanks Han. I think it will be good to backport this patch to branch-20.09.

Numan


> _______________________________________________
> dev mailing list
> dev@openvswitch.org
> https://mail.openvswitch.org/mailman/listinfo/ovs-dev
>
>
Han Zhou Sept. 17, 2020, 6:09 p.m. UTC | #4
On Thu, Sep 17, 2020 at 3:26 AM Numan Siddique <numans@ovn.org> wrote:
>
>
>
> On Thu, Sep 17, 2020 at 1:01 PM Han Zhou <hzhou@ovn.org> wrote:
>>
>> On Thu, Sep 17, 2020 at 12:25 AM Dumitru Ceara <dceara@redhat.com> wrote:
>> >
>> > On 9/16/20 6:05 PM, Han Zhou wrote:
>> > > The name was misleading because it in fact parses lflow match instead
>> > > of actions.
>> > >
>> > > Fixes: 1213bc8270 ("ovn-controller: Cache logical flow expr
matches.")
>> > > Cc: Numan Siddique <numans@ovn.org>
>> > > Acked-by: Numan Siddique <numans@ovn.org>
>> > > Signed-off-by: Han Zhou <hzhou@ovn.org>
>> > > ---
>> > > v1 -> v2: Address Dumitru's comments for the indentation.
>> > >
>> > >  controller/lflow.c | 20 ++++++++++----------
>> > >  1 file changed, 10 insertions(+), 10 deletions(-)
>> > >
>> > > diff --git a/controller/lflow.c b/controller/lflow.c
>> > > index e785866..cf5cf9f 100644
>> > > --- a/controller/lflow.c
>> > > +++ b/controller/lflow.c
>> > > @@ -720,15 +720,15 @@ add_matches_to_flow_table(const struct
>> sbrec_logical_flow *lflow,
>> > >      ofpbuf_uninit(&ofpacts);
>> > >  }
>> > >
>> > > -/* Converts the actions and returns the simplified expre tree.
>> > > +/* Converts the match and returns the simplified expre tree.
>> > >   * The caller should evaluate the conditions and normalize the
>> > >   * expr tree. */
>> > >  static struct expr *
>> > > -convert_acts_to_expr(const struct sbrec_logical_flow *lflow,
>> > > -                     struct expr *prereqs,
>> > > -                     struct lflow_ctx_in *l_ctx_in,
>> > > -                     struct lflow_ctx_out *l_ctx_out,
>> > > -                     bool *pg_addr_set_ref, char **errorp)
>> > > +convert_match_to_expr(const struct sbrec_logical_flow *lflow,
>> > > +                      struct expr *prereqs,
>> > > +                      struct lflow_ctx_in *l_ctx_in,
>> > > +                      struct lflow_ctx_out *l_ctx_out,
>> > > +                      bool *pg_addr_set_ref, char **errorp)
>> > >  {
>> > >      struct sset addr_sets_ref = SSET_INITIALIZER(&addr_sets_ref);
>> > >      struct sset port_groups_ref =
SSET_INITIALIZER(&port_groups_ref);
>> > > @@ -861,8 +861,8 @@ consider_logical_flow(const struct
>> sbrec_logical_flow *lflow,
>> > >      struct expr *expr = NULL;
>> > >      if (!l_ctx_out->lflow_cache_map) {
>> > >          /* Caching is disabled. */
>> > > -        expr = convert_acts_to_expr(lflow, prereqs, l_ctx_in,
>> > > -                                    l_ctx_out, NULL, &error);
>> > > +        expr = convert_match_to_expr(lflow, prereqs, l_ctx_in,
>> > > +                                     l_ctx_out, NULL, &error);
>> > >          if (error) {
>> > >              expr_destroy(prereqs);
>> > >              ovnacts_free(ovnacts.data, ovnacts.size);
>> > > @@ -924,8 +924,8 @@ consider_logical_flow(const struct
>> sbrec_logical_flow *lflow,
>> > >
>> > >      bool pg_addr_set_ref = false;
>> > >      if (!expr) {
>> > > -        expr = convert_acts_to_expr(lflow, prereqs, l_ctx_in,
>> l_ctx_out,
>> > > -                                    &pg_addr_set_ref, &error);
>> > > +        expr = convert_match_to_expr(lflow, prereqs, l_ctx_in,
>> l_ctx_out,
>> > > +                                     &pg_addr_set_ref, &error);
>> > >          if (error) {
>> > >              expr_destroy(prereqs);
>> > >              ovnacts_free(ovnacts.data, ovnacts.size);
>> > >
>> >
>> > Acked-by: Dumitru Ceara <dceara@redhat.com>
>> >
>> > Thanks,
>> > Dumitru
>> >
>>
>> Thanks Numan and Dumitru. I applied this to master.
>
>
> Thanks Han. I think it will be good to backport this patch to
branch-20.09.
>
Done
diff mbox series

Patch

diff --git a/controller/lflow.c b/controller/lflow.c
index e785866..cf5cf9f 100644
--- a/controller/lflow.c
+++ b/controller/lflow.c
@@ -720,15 +720,15 @@  add_matches_to_flow_table(const struct sbrec_logical_flow *lflow,
     ofpbuf_uninit(&ofpacts);
 }
 
 /* Converts the actions and returns the simplified expre tree.
  * The caller should evaluate the conditions and normalize the
  * expr tree. */
 static struct expr *
-convert_acts_to_expr(const struct sbrec_logical_flow *lflow,
-                     struct expr *prereqs,
-                     struct lflow_ctx_in *l_ctx_in,
-                     struct lflow_ctx_out *l_ctx_out,
-                     bool *pg_addr_set_ref, char **errorp)
+convert_match_to_expr(const struct sbrec_logical_flow *lflow,
+                      struct expr *prereqs,
+                      struct lflow_ctx_in *l_ctx_in,
+                      struct lflow_ctx_out *l_ctx_out,
+                      bool *pg_addr_set_ref, char **errorp)
 {
     struct sset addr_sets_ref = SSET_INITIALIZER(&addr_sets_ref);
     struct sset port_groups_ref = SSET_INITIALIZER(&port_groups_ref);
@@ -861,8 +861,8 @@  consider_logical_flow(const struct sbrec_logical_flow *lflow,
     struct expr *expr = NULL;
     if (!l_ctx_out->lflow_cache_map) {
         /* Caching is disabled. */
-        expr = convert_acts_to_expr(lflow, prereqs, l_ctx_in,
-                                    l_ctx_out, NULL, &error);
+        expr = convert_match_to_expr(lflow, prereqs, l_ctx_in,
+                                     l_ctx_out, NULL, &error);
         if (error) {
             expr_destroy(prereqs);
             ovnacts_free(ovnacts.data, ovnacts.size);
@@ -924,8 +924,8 @@  consider_logical_flow(const struct sbrec_logical_flow *lflow,
 
     bool pg_addr_set_ref = false;
     if (!expr) {
-        expr = convert_acts_to_expr(lflow, prereqs, l_ctx_in, l_ctx_out,
-                                    &pg_addr_set_ref, &error);
+        expr = convert_match_to_expr(lflow, prereqs, l_ctx_in, l_ctx_out,
+                                     &pg_addr_set_ref, &error);
         if (error) {
             expr_destroy(prereqs);
             ovnacts_free(ovnacts.data, ovnacts.size);
@@ -720,15 +720,15 @@  add_matches_to_flow_table(const struct sbrec_logical_flow *lflow,
 }
 
-/* Converts the actions and returns the simplified expre tree.
+/* Converts the match and returns the simplified expre tree.
  * The caller should evaluate the conditions and normalize the
  * expr tree. */